@@ -1,3 +1,11 @@
+"""
+$description Internet portal in Estonia, Latvia, and Lithuania providing daily news, ranging from gardening to politics.
+$url delfi.lt
+$url delfi.ee
+$url delfi.lv
+$type vod
+"""
+
 import itertools
 import logging
 import re
@@ -9,12 +17,13 @@ from streamlink.stream.hls import HLSStream
 from streamlink.utils.parse import parse_qsd
 from streamlink.utils.url import update_scheme
 
+
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(
-    r"https?://(?:[\w-]+\.)?delfi\.(?P<tld>lt|lv|ee)"
-))
+@pluginmatcher(
+    re.compile(r"https?://(?:[\w-]+\.)?delfi\.(?P<tld>lt|lv|ee)"),
+)
 class Delfi(Plugin):
     _api = {
         "lt": "https://g2.dcdn.lt/vfe/data.php",
@@ -37,17 +46,19 @@ class Delfi(Plugin):
                         "data": {
                             "versions": {
                                 str: validate.all(
-                                    [{
-                                        "type": str,
-                                        "src": str,
-                                    }],
-                                    validate.filter(lambda item: item["type"] == "application/x-mpegurl")
-                                )
-                            }
-                        }
+                                    [
+                                        {
+                                            "type": str,
+                                            "src": str,
+                                        },
+                                    ],
+                                    validate.filter(lambda item: item["type"] == "application/x-mpegurl"),
+                                ),
+                            },
+                        },
                     },
-                    validate.get(("data", "versions"))
-                )
+                    validate.get(("data", "versions")),
+                ),
             )
         except PluginError:
             log.error("Failed to get streams from API")
@@ -59,25 +70,31 @@ class Delfi(Plugin):
 
     def _get_streams_delfi(self, src):
         try:
-            data = self.session.http.get(src, schema=validate.Schema(
-                validate.parse_html(),
-                validate.xml_xpath_string(".//script[contains(text(),'embedJs.setAttribute(')][1]/text()"),
-                validate.any(None, validate.all(
-                    str,
-                    validate.transform(re.compile(r"embedJs\.setAttribute\('src',\s*'(.+?)'").search),
-                    validate.any(None, validate.all(
-                        validate.get(1),
-                        validate.transform(lambda url: parse_qsd(urlparse(url).fragment)),
-                        {"stream": str},
-                        validate.get("stream"),
-                        validate.parse_json(),
-                        {"versions": [{
-                            "hls": str
-                        }]},
-                        validate.get("versions")
-                    ))
-                ))
-            ))
+            data = self.session.http.get(
+                src,
+                schema=validate.Schema(
+                    validate.parse_html(),
+                    validate.xml_xpath_string(".//script[contains(text(),'embedJs.setAttribute(')][1]/text()"),
+                    validate.none_or_all(
+                        re.compile(r"embedJs\.setAttribute\('src',\s*'(.+?)'"),
+                        validate.none_or_all(
+                            validate.get(1),
+                            validate.transform(lambda url: parse_qsd(urlparse(url).fragment)),
+                            {"stream": str},
+                            validate.get("stream"),
+                            validate.parse_json(),
+                            {
+                                "versions": [
+                                    {
+                                        "hls": str,
+                                    },
+                                ],
+                            },
+                            validate.get("versions"),
+                        ),
+                    ),
+                ),
+            )
         except PluginError:
             log.error("Failed to get streams from iframe")
             return
@@ -87,9 +104,12 @@ class Delfi(Plugin):
             yield from HLSStream.parse_variant_playlist(self.session, src).items()
 
     def _get_streams(self):
-        root = self.session.http.get(self.url, schema=validate.Schema(
-            validate.parse_html()
-        ))
+        root = self.session.http.get(
+            self.url,
+            schema=validate.Schema(
+                validate.parse_html(),
+            ),
+        )
 
         video_id = root.xpath("string(.//div[@data-provider='dvideo'][@data-id][1]/@data-id)")
         if video_id:
