@@ -11,15 +11,28 @@ import time
 
 from streamlink.plugin import Plugin, pluginargument, pluginmatcher
 from streamlink.plugin.api import useragents
-from streamlink.stream.hls import HLSStream
+from streamlink.stream.hls import HLSStream, HLSStreamReader, HLSStreamWriter
 
 
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(
-    r"https?://(?:www\.)?yupptv\.com",
-))
+class HLSStreamWriterYupptv(HLSStreamWriter):
+    def should_filter_segment(self, segment):
+        return ".ts" not in segment.uri or super().should_filter_segment(segment)
+
+
+class HLSStreamReaderYupptv(HLSStreamReader):
+    __writer__ = HLSStreamWriterYupptv
+
+
+class HLSStreamYupptv(HLSStream):
+    __reader__ = HLSStreamReaderYupptv
+
+
+@pluginmatcher(
+    re.compile(r"https?://(?:www\.)?yupptv\.com"),
+)
 @pluginargument(
     "boxid",
     requires=["yuppflixtoken"],
@@ -39,18 +52,8 @@ log = logging.getLogger(__name__)
     help="Purge cached YuppTV credentials to initiate a new session and reauthenticate.",
 )
 class YuppTV(Plugin):
-    _m3u8_re = re.compile(r"""['"](http.+\.m3u8.*?)['"]""")
     _cookie_expiry = 3600 * 24 * 365
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self._authed = (self.session.http.cookies.get("BoxId")
-                        and self.session.http.cookies.get("YuppflixToken"))
-
-    @staticmethod
-    def _override_encoding(res, **kwargs):
-        res.encoding = "utf-8"
-
     def _login_using_box_id_and_yuppflix_token(self, box_id, yuppflix_token):
         time_now = time.time()
 
@@ -76,45 +79,49 @@ class YuppTV(Plugin):
         self.session.http.headers.update({"User-Agent": useragents.CHROME})
         self.session.http.headers.update({"Origin": "https://www.yupptv.com"})
 
+        authed = (
+            self.session.http.cookies.get("BoxId")
+            and self.session.http.cookies.get("YuppflixToken")
+        )  # fmt: skip
+
         login_box_id = self.get_option("boxid")
         login_yuppflix_token = self.get_option("yuppflixtoken")
 
         if self.options.get("purge_credentials"):
             self.clear_cookies()
-            self._authed = False
+            authed = False
             log.info("All credentials were successfully removed")
 
-        if self._authed:
+        if authed:
             log.debug("Attempting to authenticate using cached cookies")
         elif login_box_id and login_yuppflix_token:
             self._login_using_box_id_and_yuppflix_token(
                 login_box_id,
                 login_yuppflix_token,
             )
-            self._authed = True
+            authed = True
 
         page = self.session.http.get(self.url)
-        if self._authed and "btnsignup" in page.text:
+        if authed and "btnsignup" in page.text:
             log.error("This device requires renewed credentials to log in")
             return
 
-        match = self._m3u8_re.search(page.text)
-        if match:
-            stream_url = match.group(1)
-            if "preview/" in stream_url:
-                if "btnsignup" in page.text:
-                    log.error("This stream requires you to login")
-                else:
-                    log.error("This stream requires a subscription")
-                return
+        match = re.search(r"""src:\s*(?P<q>["'])(?P<url>.+?)(?P=q)""", page.text)
+        if not match or "preview/" in match["url"]:
+            if "btnsignup" in page.text:
+                log.error("This stream requires you to login")
+            else:
+                log.error("This stream requires a subscription")
+            return
 
-            return HLSStream.parse_variant_playlist(self.session,
-                                                    stream_url,
-                                                    hooks={"response": self._override_encoding})
-        elif "btnsignup" in page.text:
-            log.error("This stream requires you to login")
-        elif "btnsubscribe" in page.text:
-            log.error("This stream requires a subscription")
+        def override_encoding(res, *_, **__):
+            res.encoding = "utf-8"
+
+        return HLSStreamYupptv.parse_variant_playlist(
+            self.session,
+            match["url"],
+            hooks={"response": override_encoding},
+        )
 
 
 __plugin__ = YuppTV
