@@ -4,7 +4,8 @@ from urllib.parse import parse_qsl
 
 from lxml.etree import HTML, XML
 
-from streamlink.plugin import PluginError
+from streamlink.compat import detect_encoding
+from streamlink.exceptions import PluginError
 
 
 def _parse(parser, data, name, exception, schema, *args, **kwargs):
@@ -15,7 +16,7 @@ def _parse(parser, data, name, exception, schema, *args, **kwargs):
         if len(snippet) > 35:
             snippet = f"{snippet[:35]} ..."
 
-        raise exception(f"Unable to parse {name}: {err} ({snippet})")
+        raise exception(f"Unable to parse {name}: {err} ({snippet})")  # noqa: B904
 
     if schema:
         parsed = schema.validate(parsed, name=name, exception=exception)
@@ -28,7 +29,8 @@ def parse_json(
     name="JSON",
     exception=PluginError,
     schema=None,
-    *args, **kwargs
+    *args,
+    **kwargs,
 ):
     """Wrapper around json.loads.
 
@@ -43,7 +45,8 @@ def parse_html(
     name="HTML",
     exception=PluginError,
     schema=None,
-    *args, **kwargs
+    *args,
+    **kwargs,
 ):
     """Wrapper around lxml.etree.HTML with some extras.
 
@@ -51,7 +54,21 @@ def parse_html(
      - Removes XML declarations of invalid XHTML5 documents
      - Wraps errors in custom exception with a snippet of the data in the message
     """
-    if isinstance(data, str) and data.lstrip().startswith("<?xml"):
+    # strip XML text declarations from XHTML5 documents which were incorrectly defined as HTML5
+    is_bytes = isinstance(data, bytes)
+    if data and data.lstrip()[:5].lower() == (b"<?xml" if is_bytes else "<?xml"):
+        if is_bytes:
+            # get the document's encoding using the "encoding" attribute value of the XML text declaration
+            match = re.match(rb"^\s*<\?xml\s.*?encoding=(?P<q>[\'\"])(?P<encoding>.+?)(?P=q).*?\?>", data, re.IGNORECASE)
+            if match:
+                encoding_value = detect_encoding(match["encoding"])["encoding"]
+                encoding = match["encoding"].decode(encoding_value)
+            else:
+                # no "encoding" attribute: try to figure out encoding from the document's content
+                encoding = detect_encoding(data)["encoding"]
+
+            data = data.decode(encoding)
+
         data = re.sub(r"^\s*<\?xml.+?\?>", "", data)
 
     return _parse(HTML, data, name, exception, schema, *args, **kwargs)
@@ -64,7 +81,8 @@ def parse_xml(
     name="XML",
     exception=PluginError,
     schema=None,
-    *args, **kwargs
+    *args,
+    **kwargs,
 ):
     """Wrapper around lxml.etree.XML with some extras.
 
@@ -76,9 +94,9 @@ def parse_xml(
     if isinstance(data, str):
         data = bytes(data, "utf8")
     if ignore_ns:
-        data = re.sub(br"\s+xmlns=\"(.+?)\"", b"", data)
+        data = re.sub(rb"\s+xmlns=\"(.+?)\"", b"", data)
     if invalid_char_entities:
-        data = re.sub(br"&(?!(?:#(?:[0-9]+|[Xx][0-9A-Fa-f]+)|[A-Za-z0-9]+);)", b"&amp;", data)
+        data = re.sub(rb"&(?!(?:#(?:[0-9]+|[Xx][0-9A-Fa-f]+)|[A-Za-z0-9]+);)", b"&amp;", data)
 
     return _parse(XML, data, name, exception, schema, *args, **kwargs)
 
@@ -88,7 +106,8 @@ def parse_qsd(
     name="query string",
     exception=PluginError,
     schema=None,
-    *args, **kwargs
+    *args,
+    **kwargs,
 ):
     """Parses a query string into a dict.
 
