@@ -1,11 +1,13 @@
+from __future__ import annotations
+
 import logging
 import sys
 import tempfile
-from contextlib import asynccontextmanager, contextmanager
+from collections.abc import AsyncGenerator, Generator
+from contextlib import AbstractAsyncContextManager, asynccontextmanager, contextmanager
 from functools import partial
 from pathlib import Path
 from subprocess import DEVNULL
-from typing import AsyncContextManager, AsyncGenerator, Generator, List, Optional, Union
 
 import trio
 
@@ -23,39 +25,39 @@ class Webbrowser:
     TIMEOUT = 10
 
     @classmethod
-    def names(cls) -> List[str]:
+    def names(cls) -> list[str]:
         return []
 
     @classmethod
-    def fallback_paths(cls) -> List[Union[str, Path]]:
+    def fallback_paths(cls) -> list[str | Path]:
         return []
 
     @classmethod
-    def launch_args(cls) -> List[str]:
+    def launch_args(cls) -> list[str]:
         return []
 
-    def __init__(self, executable: Optional[str] = None):
+    def __init__(self, executable: str | None = None):
         resolved = resolve_executable(executable, self.names(), self.fallback_paths())
         if not resolved:
             raise WebbrowserError(
                 f"Invalid web browser executable: {executable}"
-                if executable else
-                f"{self.ERROR_RESOLVE}: Please set the path to a supported web browser using --webbrowser-executable",
+                if executable
+                else f"{self.ERROR_RESOLVE}: Please set the path to a supported web browser using --webbrowser-executable",
             )
 
-        self.executable: Union[str, Path] = resolved
-        self.arguments: List[str] = self.launch_args().copy()
+        self.executable: str | Path = resolved
+        self.arguments: list[str] = self.launch_args().copy()
 
-    def launch(self, headless: bool = False, timeout: Optional[float] = None) -> AsyncContextManager[trio.Nursery]:
+    def launch(self, headless: bool = False, timeout: float | None = None) -> AbstractAsyncContextManager[trio.Nursery]:
         return self._launch(self.executable, self.arguments, headless=headless, timeout=timeout)
 
     def _launch(
         self,
-        executable: Union[str, Path],
-        arguments: List[str],
+        executable: str | Path,
+        arguments: list[str],
         headless: bool = False,
-        timeout: Optional[float] = None,
-    ) -> AsyncContextManager[trio.Nursery]:
+        timeout: float | None = None,
+    ) -> AbstractAsyncContextManager[trio.Nursery]:
         if timeout is None:
             timeout = self.TIMEOUT
 
@@ -73,7 +75,7 @@ class Webbrowser:
 
 
 class _WebbrowserLauncher:
-    def __init__(self, executable: Union[str, Path], arguments: List[str], headless: bool, timeout: float):
+    def __init__(self, executable: str | Path, arguments: list[str], headless: bool, timeout: float):
         self.executable = executable
         self.arguments = arguments
         self.headless = headless
@@ -112,7 +114,7 @@ class _WebbrowserLauncher:
                     # once the application logic is done, cancel the entire task group and terminate/kill the process
                     nursery.cancel_scope.cancel()
         except BaseExceptionGroup as exc_grp:  # TODO: py310 support end: use except*
-            exc: Union[BaseException, BaseExceptionGroup, None] = exc_grp.subgroup((KeyboardInterrupt, SystemExit))
+            exc: BaseException | BaseExceptionGroup | None = exc_grp.subgroup((KeyboardInterrupt, SystemExit))
             if not exc:  # not a KeyboardInterrupt or SystemExit
                 raise
             while isinstance(exc, BaseExceptionGroup):  # get the first actual exception in the potentially nested groups
