@@ -2,12 +2,13 @@ from __future__ import annotations
 
 import json
 import re
+from typing import Iterator
 from unittest.mock import Mock
 
 import pytest
 
 import streamlink_cli.main
-from streamlink.exceptions import PluginError
+from streamlink.exceptions import FatalPluginError, PluginError
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.session import Streamlink
 from streamlink.stream.stream import Stream
@@ -57,40 +58,52 @@ def _stream_output(monkeypatch: pytest.MonkeyPatch):
 
 @pytest.fixture(autouse=True)
 def streams(request: pytest.FixtureRequest, session: Streamlink):
-    param = getattr(request, "param", {})
+    params = getattr(request, "param", [{}])
+    params = params if isinstance(params, list) else [params]
 
-    if exc := param.get("exc"):
-        return exc
+    def streams_generator():
+        for param in params:
+            if exc := param.get("exc"):
+                yield exc
+                continue
 
-    streams = param.get("streams", False)
-    to_url = param.get("to_url", True)
-    to_manifest_url = param.get("to_manifest_url", True)
+            streams = param.get("streams", {})
+            to_url = param.get("to_url", True)
+            to_manifest_url = param.get("to_manifest_url", True)
 
-    return {
-        name: FakeStream(
-            session,
-            url=url if to_url else None,
-            manifest_url=STREAMS_MULTIVARIANT if to_manifest_url else None,
-        )
-        for name, url in (STREAMS if streams else {}).items()
-    }
+            yield {
+                name: FakeStream(
+                    session,
+                    url=url if to_url else None,
+                    manifest_url=STREAMS_MULTIVARIANT if to_manifest_url else None,
+                )
+                for name, url in (STREAMS if streams is True else streams).items()
+            }
+
+    return streams_generator()
 
 
 @pytest.fixture(autouse=True)
-def plugin(session: Streamlink, streams: BaseException | dict[str, FakeStream]):
+def plugin(session: Streamlink, streams: Iterator[dict[str, FakeStream]]):
     @pluginmatcher(re.compile(r"https?://plugin"))
     class FakePlugin(Plugin):
-        __module__ = "plugin"
+        __module__ = "streamlink.plugins.plugin"
 
         id = "ID"
         author = "AUTHOR"
         category = "CATEGORY"
         title = "TITLE"
 
+        def __init__(self, *args, **kwargs):
+            super().__init__(*args, **kwargs)
+            self.logger.info("plugin log message")
+
         def _get_streams(self):
-            if isinstance(streams, BaseException):
-                raise streams
-            return streams
+            item = next(streams, None)
+            if isinstance(item, BaseException):
+                raise item
+
+            return item
 
     session.plugins.update({"plugin": FakePlugin})
 
@@ -110,7 +123,8 @@ def plugin(session: Streamlink, streams: BaseException | dict[str, FakeStream]):
             {"exc": PluginError("Error while fetching streams")},
             1,
             (
-                "[cli][info] Found matching plugin plugin for URL plugin\n"  # formatter: keep separate lines
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
                 + "error: Error while fetching streams\n"
             ),
             id="fetch-streams-exception",
@@ -121,6 +135,7 @@ def plugin(session: Streamlink, streams: BaseException | dict[str, FakeStream]):
             1,
             (
                 "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
                 + "error: No playable streams found on this URL: plugin\n"
             ),
             id="no-streams",
@@ -131,6 +146,7 @@ def plugin(session: Streamlink, streams: BaseException | dict[str, FakeStream]):
             0,
             (
                 "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
                 + "Available streams: audio, 720p (worst), 1080p (best)\n"
             ),
             id="streams-selection-none",
@@ -141,6 +157,7 @@ def plugin(session: Streamlink, streams: BaseException | dict[str, FakeStream]):
             1,
             (
                 "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
                 + "error: The specified stream(s) 'one, two, three' could not be found.\n"
                 + "       Available streams: audio, 720p (worst), 1080p (best)\n"
             ),
@@ -152,6 +169,7 @@ def plugin(session: Streamlink, streams: BaseException | dict[str, FakeStream]):
             0,
             (
                 "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
                 + "[cli][info] Available streams: audio, 720p (worst), 1080p (best)\n"
                 + "[cli][info] Opening stream: 1080p (fake)\n"
             ),
@@ -305,7 +323,13 @@ def plugin(session: Streamlink, streams: BaseException | dict[str, FakeStream]):
     ],
     indirect=["argv", "streams"],
 )
-def test_handle_url(capsys: pytest.CaptureFixture[str], argv: list, streams: dict, exit_code: int, stdout: str):
+def test_handle_url_text_output(
+    capsys: pytest.CaptureFixture[str],
+    argv: list,
+    streams: Iterator[dict[str, FakeStream]],
+    exit_code: int,
+    stdout: str,
+):
     with pytest.raises(SystemExit) as exc_info:
         streamlink_cli.main.main()
 
@@ -315,6 +339,168 @@ def test_handle_url(capsys: pytest.CaptureFixture[str], argv: list, streams: dic
     assert err == ""
 
 
+@pytest.mark.parametrize(
+    ("argv", "streams", "exit_code", "retries", "stdout"),
+    [
+        pytest.param(
+            ["plugin", "best"],
+            [],
+            1,
+            0,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "error: No playable streams found on this URL: plugin\n"
+            ),
+            id="no-retries-implicit",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-streams=0", "--retry-max=0"],
+            [],
+            1,
+            0,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "error: No playable streams found on this URL: plugin\n"
+            ),
+            id="no-retries-explicit",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-max=5"],
+            [],
+            1,
+            5,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "[cli][info] Waiting for streams, retrying every 1 second(s)\n"
+                + "error: No playable streams found on this URL: plugin\n"
+            ),
+            id="no-streams",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-max=5"],
+            [{"streams": True}],
+            0,
+            0,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "[cli][info] Available streams: audio, 720p (worst), 1080p (best)\n"
+                + "[cli][info] Opening stream: 1080p (fake)\n"
+            ),
+            id="success-on-first-attempt",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-streams=3", "--retry-max=5"],
+            [{}, {}, {"streams": True}],
+            0,
+            2,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "[cli][info] Waiting for streams, retrying every 3.0 second(s)\n"
+                + "[cli][info] Available streams: audio, 720p (worst), 1080p (best)\n"
+                + "[cli][info] Opening stream: 1080p (fake)\n"
+            ),
+            id="success-on-third-attempt",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-streams=3", "--retry-max=5"],
+            [{"exc": PluginError("failure")}, {"streams": True}],
+            0,
+            1,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "[cli][error] failure\n"
+                + "[cli][info] Waiting for streams, retrying every 3.0 second(s)\n"
+                + "[cli][info] Available streams: audio, 720p (worst), 1080p (best)\n"
+                + "[cli][info] Opening stream: 1080p (fake)\n"
+            ),
+            id="success-with-plugin-error-on-first-attempt",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-streams=3", "--retry-max=5"],
+            [{}, {"exc": PluginError("failure")}, {"streams": True}],
+            0,
+            2,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "[cli][info] Waiting for streams, retrying every 3.0 second(s)\n"
+                + "[cli][error] failure\n"
+                + "[cli][info] Available streams: audio, 720p (worst), 1080p (best)\n"
+                + "[cli][info] Opening stream: 1080p (fake)\n"
+            ),
+            id="success-with-plugin-error-on-second-attempt",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-streams=3"],
+            [{} for _ in range(20)] + [{"streams": True}],
+            0,
+            20,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "[cli][info] Waiting for streams, retrying every 3.0 second(s)\n"
+                + "[cli][info] Available streams: audio, 720p (worst), 1080p (best)\n"
+                + "[cli][info] Opening stream: 1080p (fake)\n"
+            ),
+            id="success-no-max-attempts",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-max=5"],
+            [{"exc": FatalPluginError("fatal")}, {"streams": True}],
+            1,
+            0,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "error: fatal\n"
+            ),
+            id="fatal-plugin-error-on-first-attempt",
+        ),
+        pytest.param(
+            ["plugin", "best", "--retry-max=5"],
+            [{}, {"exc": FatalPluginError("fatal")}, {"streams": True}],
+            1,
+            1,
+            (
+                "[cli][info] Found matching plugin plugin for URL plugin\n"
+                + "[plugins.plugin][info] plugin log message\n"
+                + "[cli][info] Waiting for streams, retrying every 1 second(s)\n"
+                + "error: fatal\n"
+            ),
+            id="fatal-plugin-error-on-second-attempt",
+        ),
+    ],
+    indirect=["argv", "streams"],
+)  # fmt: skip
+def test_handle_url_retry(
+    monkeypatch: pytest.MonkeyPatch,
+    capsys: pytest.CaptureFixture[str],
+    argv: list,
+    streams: Iterator[dict[str, FakeStream]],
+    exit_code: int,
+    retries: int,
+    stdout: list[str],
+):
+    mock_sleep = Mock()
+    monkeypatch.setattr("streamlink_cli.main.sleep", mock_sleep)
+
+    with pytest.raises(SystemExit) as exc_info:
+        streamlink_cli.main.main()
+
+    assert exc_info.value.code == exit_code
+    assert mock_sleep.call_count == retries
+
+    out, err = capsys.readouterr()
+    assert out == stdout
+    assert err == ""
+
+
 @pytest.mark.parametrize("argv", [pytest.param(["plugin", "best"], id="argv")], indirect=["argv"])
 class TestHandleUrlKeyboardInterruptAndCleanup:
     @pytest.fixture(autouse=True)
