@@ -1,4 +1,6 @@
-from typing import Mapping
+from __future__ import annotations
+
+from collections.abc import Mapping
 from unittest.mock import Mock
 
 import pytest
