@@ -6,6 +6,6 @@ class TestPluginCanHandleUrlBrightcove(PluginCanHandleUrl):
     __plugin__ = Brightcove
 
     should_match = [
-        'http://players.brightcove.net/123/default_default/index.html?videoId=456',
-        'http://players.brightcove.net/456/default_default/index.html?videoId=789',
+        "https://players.brightcove.net/123/default_default/index.html?videoId=456",
+        "https://players.brightcove.net/456/default_default/index.html?videoId=789",
     ]
