@@ -6,6 +6,6 @@ class TestPluginCanHandleUrlEarthCam(PluginCanHandleUrl):
     __plugin__ = EarthCam
 
     should_match = [
-        'https://www.earthcam.com/usa/newyork/timessquare/?cam=tsstreet',
-        'https://www.earthcam.com/usa/newyork/timessquare/?cam=gts1',
+        "https://www.earthcam.com/usa/newyork/timessquare/?cam=tsstreet",
+        "https://www.earthcam.com/usa/newyork/timessquare/?cam=gts1",
     ]
