@@ -6,5 +6,5 @@ class TestPluginCanHandleUrlGoogleDocs(PluginCanHandleUrl):
     __plugin__ = GoogleDocs
 
     should_match = [
-        'https://drive.google.com/file/d/123123/preview?start=1',
+        "https://drive.google.com/file/d/123123/preview?start=1",
     ]
