@@ -13,9 +13,9 @@ class TestPluginCanHandleUrlN13TV(PluginCanHandleUrl):
         "http://13tv.co.il/item/entertainment/ambush/season-02/episodes/ffuk3-2026112/",
         "https://13tv.co.il/item/entertainment/ambush/season-02/episodes/ffuk3-2026112/",
         "http://www.13tv.co.il/item/entertainment/ambush/season-02/episodes/ffuk3-2026112/",
-        "https://www.13tv.co.il/item/entertainment/ambush/season-02/episodes/ffuk3-2026112/"
+        "https://www.13tv.co.il/item/entertainment/ambush/season-02/episodes/ffuk3-2026112/",
         "http://13tv.co.il/item/entertainment/tzhok-mehamatzav/season-01/episodes/vkdoc-2023442/",
         "https://13tv.co.il/item/entertainment/tzhok-mehamatzav/season-01/episodes/vkdoc-2023442/",
-        "http://www.13tv.co.il/item/entertainment/tzhok-mehamatzav/season-01/episodes/vkdoc-2023442/"
-        "https://www.13tv.co.il/item/entertainment/tzhok-mehamatzav/season-01/episodes/vkdoc-2023442/"
+        "http://www.13tv.co.il/item/entertainment/tzhok-mehamatzav/season-01/episodes/vkdoc-2023442/",
+        "https://www.13tv.co.il/item/entertainment/tzhok-mehamatzav/season-01/episodes/vkdoc-2023442/",
     ]
