@@ -6,6 +6,6 @@ class TestPluginCanHandleUrlZeeNews(PluginCanHandleUrl):
     __plugin__ = ZeeNews
 
     should_match = [
-        'https://zeenews.india.com/live-tv',
-        'https://zeenews.india.com/live-tv/embed',
+        "https://zeenews.india.com/live-tv",
+        "https://zeenews.india.com/live-tv/embed",
     ]
