@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import base64
 import hashlib
 import re
@@ -5,7 +7,7 @@ import re
 # noinspection PyProtectedMember
 from importlib.metadata import FileHash, PackagePath
 from pathlib import Path
-from typing import Optional, Type, cast
+from typing import cast
 from unittest.mock import Mock, call
 
 import pytest
@@ -38,7 +40,8 @@ PATH_TESTPLUGINS_OVERRIDE = PATH_TESTPLUGINS / "override"
 
 
 class _Plugin(Plugin):
-    def _get_streams(self): pass  # pragma: no cover
+    def _get_streams(self):  # pragma: no cover
+        pass
 
 
 @pytest.fixture(autouse=True)
@@ -49,7 +52,7 @@ def caplog(caplog: pytest.LogCaptureFixture) -> pytest.LogCaptureFixture:
 
 @pytest.fixture(scope="module")
 def fake_plugin():
-    @pluginmatcher(re.compile("fake"))
+    @pluginmatcher(re.compile(r"fake"))
     @pluginargument("foo")
     @pluginargument("bar")
     class FakePlugin(_Plugin):
@@ -64,7 +67,7 @@ def test_empty(caplog: pytest.LogCaptureFixture, session: Streamlink):
     assert caplog.record_tuples == []
 
 
-def test_set_get_del(session: Streamlink, fake_plugin: Type[Plugin]):
+def test_set_get_del(session: Streamlink, fake_plugin: type[Plugin]):
     assert "fake" not in session.plugins
 
     session.plugins["fake"] = fake_plugin
@@ -80,7 +83,7 @@ def test_set_get_del(session: Streamlink, fake_plugin: Type[Plugin]):
     assert session.plugins.get_loaded() == {}
 
 
-def test_update_clear(session: Streamlink, fake_plugin: Type[Plugin]):
+def test_update_clear(session: Streamlink, fake_plugin: type[Plugin]):
     assert "fake" not in session.plugins
 
     session.plugins.update({"fake": fake_plugin})
@@ -95,7 +98,7 @@ def test_update_clear(session: Streamlink, fake_plugin: Type[Plugin]):
     assert session.plugins.get_loaded() == {}
 
 
-def test_iter_arguments(session: Streamlink, fake_plugin: Type[Plugin]):
+def test_iter_arguments(session: Streamlink, fake_plugin: type[Plugin]):
     session.plugins.update({"fake": fake_plugin})
     assert [(name, [arg.argument_name(name) for arg in args]) for name, args in session.plugins.iter_arguments()] == [
         ("fake", ["--fake-foo", "--fake-bar"]),
@@ -103,7 +106,7 @@ def test_iter_arguments(session: Streamlink, fake_plugin: Type[Plugin]):
 
 
 class TestLoad:
-    def test_load_builtin(self, monkeypatch: pytest.MonkeyPatch, caplog: pytest.LogCaptureFixture, fake_plugin: Type[Plugin]):
+    def test_load_builtin(self, monkeypatch: pytest.MonkeyPatch, caplog: pytest.LogCaptureFixture, fake_plugin: type[Plugin]):
         mock = Mock(return_value={"fake": fake_plugin})
         monkeypatch.setattr(StreamlinkPlugins, "_load_plugins_from_path", mock)
         session = Streamlink(plugins_builtin=True, plugins_lazy=False)
@@ -145,7 +148,8 @@ class TestLoad:
             (
                 "streamlink.session",
                 "info",
-                f"Plugin testplugin is being overridden by {PATH_TESTPLUGINS_OVERRIDE / 'testplugin.py'}",
+                f"Plugin testplugin is being overridden by {PATH_TESTPLUGINS_OVERRIDE / 'testplugin.py'}"
+                + " (sha256:47d9c5ec4167565db13aae76f2fbedcf961f5fca386e60c4384ee5e92714b5f3)",
             ),
         ]
 
@@ -165,7 +169,8 @@ class TestLoad:
             (
                 "streamlink.session",
                 "info",
-                f"Plugin testplugin is being overridden by {PATH_TESTPLUGINS / 'testplugin.py'}",
+                f"Plugin testplugin is being overridden by {PATH_TESTPLUGINS / 'testplugin.py'}"
+                + " (sha256:088c9f6ddbe5ff046c0ea1ce0cacb7baff46189d153cf3f149b2e023ddf66f6c)",
             ),
         ]
 
@@ -205,7 +210,7 @@ class TestLoad:
 
 class TestLoadPluginsData:
     @pytest.fixture()
-    def session(self, monkeypatch: pytest.MonkeyPatch, fake_plugin: Type[Plugin], metadata_files: Mock):
+    def session(self, monkeypatch: pytest.MonkeyPatch, fake_plugin: type[Plugin], metadata_files: Mock):
         class MockStreamlinkPlugins(StreamlinkPlugins):
             def load_builtin(self):
                 self._plugins.update({"fake": fake_plugin})
@@ -216,7 +221,7 @@ class TestLoadPluginsData:
         return Streamlink(plugins_builtin=True, plugins_lazy=True)
 
     @pytest.fixture(autouse=True)
-    def metadata_files(self, request: pytest.FixtureRequest, monkeypatch: pytest.MonkeyPatch, pluginsdata: Optional[str]):
+    def metadata_files(self, request: pytest.FixtureRequest, monkeypatch: pytest.MonkeyPatch, pluginsdata: str | None):
         options = getattr(request, "param", {})
         package_record = options.get("package-record", True)
         mode = options.get("package-record-hash-mode", "sha256")
@@ -257,59 +262,96 @@ class TestLoadPluginsData:
         return data
 
     # noinspection PyTestParametrized
-    @pytest.mark.parametrize(("metadata_files", "pluginsdata", "logs"), [
-        pytest.param(
-            {},
-            None,
-            [],
-            id="empty-json-file",
-        ),
-        pytest.param(
-            {"package-record": False},
-            """{}""",
-            [],
-            id="no-package-record",
-        ),
-        pytest.param(
-            {"package-record-hash-mode": "unknown"},
-            """{}""",
-            [("streamlink.session", "error", "Unknown plugins data hash mode, falling back to loading all plugins")],
-            id="invalid-package-record-hash-mode",
-        ),
-        pytest.param(
-            {"package-record-hash-value": "invalid"},
-            """{}""",
-            [("streamlink.session", "error", "Plugins data checksum mismatch, falling back to loading all plugins")],
-            id="invalid-package-record-hash-value",
-        ),
-    ], indirect=["metadata_files", "pluginsdata"])
+    @pytest.mark.parametrize(
+        ("metadata_files", "pluginsdata", "logs"),
+        [
+            pytest.param(
+                {},
+                None,
+                [],
+                id="empty-json-file",
+            ),
+            pytest.param(
+                {"package-record": False},
+                """{}""",
+                [],
+                id="no-package-record",
+            ),
+            pytest.param(
+                {"package-record-hash-mode": "unknown"},
+                """{}""",
+                [("streamlink.session", "error", "Unknown plugins data hash mode, falling back to loading all plugins")],
+                id="invalid-package-record-hash-mode",
+            ),
+            pytest.param(
+                {"package-record-hash-value": "invalid"},
+                """{}""",
+                [("streamlink.session", "error", "Plugins data checksum mismatch, falling back to loading all plugins")],
+                id="invalid-package-record-hash-value",
+            ),
+        ],
+        indirect=["metadata_files", "pluginsdata"],
+    )
     def test_fallback_load_builtin(self, caplog: pytest.LogCaptureFixture, session: Streamlink, logs: list):
         assert session.plugins.get_names() == ["fake"]
         assert [(record.name, record.levelname, record.message) for record in caplog.get_records(when="setup")] == logs
 
-    @pytest.mark.parametrize("pluginsdata", [
-        pytest.param(
-            # language=json
-            """
-                {
-                    "testpluginA": {
-                        "matchers": [
-                            {"pattern": "foo"},
-                            {"pattern": "bar", "flags": 64, "priority": 10, "name": "bar"}
-                        ],
-                        "arguments": []
-                    },
-                    "testpluginB": {
-                        "matchers": [
-                            {"pattern": "baz"}
-                        ],
-                        "arguments": []
+    # noinspection JsonStandardCompliance
+    @pytest.mark.parametrize(
+        "pluginsdata",
+        [
+            pytest.param(
+                # language=json
+                """
+                    // foo
+                    // bar
+                    {
+                        "testplugin": {
+                            "matchers": [
+                                {"pattern": "foo"}
+                            ],
+                            "arguments": []
+                        }
                     }
-                }
-            """,
-            id="matchers",
-        ),
-    ], indirect=True)
+                """,
+                id="json-comments",
+            ),
+        ],
+        indirect=True,
+    )
+    def test_strip_json_comment(self, caplog: pytest.LogCaptureFixture, session: Streamlink, pluginsdata: str):
+        assert "fake" not in session.plugins
+        assert "testplugin" not in session.plugins
+        assert session.plugins.get_names() == ["testplugin"]
+        assert [(record.name, record.levelname, record.message) for record in caplog.get_records(when="setup")] == []
+
+    @pytest.mark.parametrize(
+        "pluginsdata",
+        [
+            pytest.param(
+                # language=json
+                """
+                    {
+                        "testpluginA": {
+                            "matchers": [
+                                {"pattern": "foo"},
+                                {"pattern": "bar", "flags": 64, "priority": 10, "name": "bar"}
+                            ],
+                            "arguments": []
+                        },
+                        "testpluginB": {
+                            "matchers": [
+                                {"pattern": "baz"}
+                            ],
+                            "arguments": []
+                        }
+                    }
+                """,
+                id="matchers",
+            ),
+        ],
+        indirect=True,
+    )
     def test_matchers(self, caplog: pytest.LogCaptureFixture, session: Streamlink, pluginsdata: str):
         assert "fake" not in session.plugins
         assert "testpluginA" not in session.plugins
@@ -318,30 +360,34 @@ class TestLoadPluginsData:
         assert [(record.name, record.levelname, record.message) for record in caplog.get_records(when="setup")] == []
 
         matchers_a = Matchers()
-        matchers_a.register(Matcher(pattern=re.compile(r"foo"), priority=NORMAL_PRIORITY, name=None))
-        matchers_a.register(Matcher(pattern=re.compile(r"bar", re.VERBOSE), priority=10, name="bar"))
+        matchers_a.add(Matcher(pattern=re.compile(r"foo"), priority=NORMAL_PRIORITY, name=None))
+        matchers_a.add(Matcher(pattern=re.compile(r"bar", re.VERBOSE), priority=10, name="bar"))
         matchers_b = Matchers()
-        matchers_b.register(Matcher(pattern=re.compile(r"baz"), priority=NORMAL_PRIORITY, name=None))
+        matchers_b.add(Matcher(pattern=re.compile(r"baz"), priority=NORMAL_PRIORITY, name=None))
         assert list(session.plugins.iter_matchers()) == [("testpluginA", matchers_a), ("testpluginB", matchers_b)]
 
-    @pytest.mark.parametrize("pluginsdata", [
-        pytest.param(
-            # language=json
-            """
-                {
-                    "success": {
-                        "matchers": [{"pattern": "foo"}],
-                        "arguments": []
-                    },
-                    "fail": {
-                        "matchers": [{"pattern": {"invalid": "type"}}],
-                        "arguments": []
+    @pytest.mark.parametrize(
+        "pluginsdata",
+        [
+            pytest.param(
+                # language=json
+                """
+                    {
+                        "success": {
+                            "matchers": [{"pattern": "foo"}],
+                            "arguments": []
+                        },
+                        "fail": {
+                            "matchers": [{"pattern": {"invalid": "type"}}],
+                            "arguments": []
+                        }
                     }
-                }
-            """,
-            id="matchers",
-        ),
-    ], indirect=True)
+                """,
+                id="matchers",
+            ),
+        ],
+        indirect=True,
+    )
     def test_matchers_failure(self, caplog: pytest.LogCaptureFixture, session: Streamlink, pluginsdata: str):
         assert "fake" in session.plugins
         assert "success" not in session.plugins
@@ -352,59 +398,63 @@ class TestLoadPluginsData:
             ("streamlink.session", "error", "Error while loading pluginmatcher data from JSON"),
         ]
 
-    @pytest.mark.parametrize("pluginsdata", [
-        pytest.param(
-            # language=json
-            """
-                {
-                    "empty": {
-                        "matchers": [{"pattern": "foo"}]
-                    },
-                    "testpluginA": {
-                        "matchers": [{"pattern": "bar"}],
-                        "arguments": [
-                            {
-                                "name": "foo",
-                                "action": "store",
-                                "nargs": 1,
-                                "default": "foo",
-                                "choices": ["foo", "bar"],
-                                "required": true,
-                                "help": "foo",
-                                "metavar": "FOO",
-                                "dest": "oof",
-                                "argument_name": "oof"
-                            },
-                            {
-                                "name": "bar",
-                                "const": "bar"
-                            }
-                        ]
-                    },
-                    "testpluginB": {
-                        "matchers": [{"pattern": "baz"}],
-                        "arguments": [
-                            {
-                                "name": "invalid",
-                                "type": "type_which_does_not_exist"
-                            },
-                            {
-                                "name": "bool",
-                                "type": "bool"
-                            },
-                            {
-                                "name": "cmf",
-                                "type": "comma_list_filter",
-                                "type_args": [["1", "2", "3"]],
-                                "type_kwargs": {"unique": true}
-                            }
-                        ]
+    @pytest.mark.parametrize(
+        "pluginsdata",
+        [
+            pytest.param(
+                # language=json
+                """
+                    {
+                        "empty": {
+                            "matchers": [{"pattern": "foo"}]
+                        },
+                        "testpluginA": {
+                            "matchers": [{"pattern": "bar"}],
+                            "arguments": [
+                                {
+                                    "name": "foo",
+                                    "action": "store",
+                                    "nargs": 1,
+                                    "default": "foo",
+                                    "choices": ["foo", "bar"],
+                                    "required": true,
+                                    "help": "foo",
+                                    "metavar": "FOO",
+                                    "dest": "oof",
+                                    "argument_name": "oof"
+                                },
+                                {
+                                    "name": "bar",
+                                    "const": "bar"
+                                }
+                            ]
+                        },
+                        "testpluginB": {
+                            "matchers": [{"pattern": "baz"}],
+                            "arguments": [
+                                {
+                                    "name": "invalid",
+                                    "type": "type_which_does_not_exist"
+                                },
+                                {
+                                    "name": "bool",
+                                    "type": "bool"
+                                },
+                                {
+                                    "name": "cmf",
+                                    "type": "comma_list_filter",
+                                    "type_args": [["1", "2", "3"]],
+                                    "type_kwargs": {"unique": true}
+                                }
+                            ]
+                        }
                     }
-                }
-            """,
-            id="arguments",
-        ),
-    ], indirect=True)
+                """,
+                id="arguments",
+            ),
+        ],
+        indirect=True,
+    )
     def test_arguments(self, caplog: pytest.LogCaptureFixture, session: Streamlink, pluginsdata: str):
         assert "fake" not in session.plugins
         assert "testpluginA" not in session.plugins
@@ -415,51 +465,63 @@ class TestLoadPluginsData:
         # arguments are added in reverse order:
         # `Arguments` does this because of the reverse order of the @pluginargument decorator
         arguments_a = Arguments()
-        arguments_a.add(Argument(
-            name="bar",
-            const="bar",
-        ))
-        arguments_a.add(Argument(
-            name="foo",
-            action="store",
-            nargs=1,
-            default="foo",
-            choices=["foo", "bar"],
-            required=True,
-            help="foo",
-            metavar="FOO",
-            dest="oof",
-            argument_name="oof",
-        ))
+        arguments_a.add(
+            Argument(
+                name="bar",
+                const="bar",
+            ),
+        )
+        arguments_a.add(
+            Argument(
+                name="foo",
+                action="store",
+                nargs=1,
+                default="foo",
+                choices=["foo", "bar"],
+                required=True,
+                help="foo",
+                metavar="FOO",
+                dest="oof",
+                argument_name="oof",
+            ),
+        )
         arguments_b = Arguments()
-        arguments_b.add(Argument(
-            name="cmf",
-            type=comma_list_filter(["1", "2", "3"], unique=True),
-        ))
-        arguments_b.add(Argument(
-            name="bool",
-            type=boolean,
-        ))
+        arguments_b.add(
+            Argument(
+                name="cmf",
+                type=comma_list_filter(["1", "2", "3"], unique=True),
+            ),
+        )
+        arguments_b.add(
+            Argument(
+                name="bool",
+                type=boolean,
+            ),
+        )
         assert list(session.plugins.iter_arguments()) == [("testpluginA", arguments_a), ("testpluginB", arguments_b)]
 
-    @pytest.mark.parametrize("pluginsdata", [
-        pytest.param(
-            # language=json
-            """
-                {
-                    "success": {
-                        "matchers": [{"pattern": "foo"}],
-                        "arguments": [{"name": "foo"}]
-                    },
-                    "fail": {
-                        "matchers": [{"pattern": "bar"}],
-                        "arguments": [{"name": {"invalid": "type"}}]
+    @pytest.mark.parametrize(
+        "pluginsdata",
+        [
+            pytest.param(
+                # language=json
+                """
+                    {
+                        "success": {
+                            "matchers": [{"pattern": "foo"}],
+                            "arguments": [{"name": "foo"}]
+                        },
+                        "fail": {
+                            "matchers": [{"pattern": "bar"}],
+                            "arguments": [{"name": {"invalid": "type"}}]
+                        }
                     }
-                }
-            """,
-            id="arguments",
-        ),
-    ], indirect=True)
+                """,
+                id="arguments",
+            ),
+        ],
+        indirect=True,
+    )
     def test_arguments_failure(self, caplog: pytest.LogCaptureFixture, session: Streamlink, pluginsdata: str):
         assert "fake" in session.plugins
         assert "success" not in session.plugins
@@ -473,19 +535,19 @@ class TestLoadPluginsData:
 
 class TestMatchURL:
     def test_priority(self, session: Streamlink):
-        @pluginmatcher(priority=HIGH_PRIORITY, pattern=re.compile("^(high|normal|low|no)$"))
+        @pluginmatcher(priority=HIGH_PRIORITY, pattern=re.compile(r"^(high|normal|low|no)$"))
         class HighPriority(_Plugin):
             pass
 
-        @pluginmatcher(priority=NORMAL_PRIORITY, pattern=re.compile("^(normal|low|no)$"))
+        @pluginmatcher(priority=NORMAL_PRIORITY, pattern=re.compile(r"^(normal|low|no)$"))
         class NormalPriority(_Plugin):
             pass
 
-        @pluginmatcher(priority=LOW_PRIORITY, pattern=re.compile("^(low|no)$"))
+        @pluginmatcher(priority=LOW_PRIORITY, pattern=re.compile(r"^(low|no)$"))
         class LowPriority(_Plugin):
             pass
 
-        @pluginmatcher(priority=NO_PRIORITY, pattern=re.compile("^no$"))
+        @pluginmatcher(priority=NO_PRIORITY, pattern=re.compile(r"^no$"))
         class NoPriority(_Plugin):
             pass
 
@@ -509,7 +571,7 @@ class TestMatchURL:
         assert session.plugins.match_url("high") is None
 
     def test_no_priority(self, session: Streamlink):
-        @pluginmatcher(priority=NO_PRIORITY, pattern=re.compile("^no$"))
+        @pluginmatcher(priority=NO_PRIORITY, pattern=re.compile(r"^no$"))
         class NoPriority(_Plugin):
             pass
 
